@@ -17,6 +17,8 @@
 #include <libart_lgpl/art_affine.h>
 #include <libart_lgpl/art_filterlevel.h>
 #include "rgb-stuff.h"
+#include <gdk/gdkx.h>
+#include <X11/Xatom.h>
 
 GSList *panels = NULL; /*other panels we might want to move the applet to*/
 
@@ -27,6 +29,9 @@ GSList *panels = NULL; /*other panels we might want to move the applet to*/
 we only have one mouse :) */
 gboolean panel_applet_in_drag = FALSE;
 
+/* Commie mode! */
+extern gboolean commie_mode;
+
 static void panel_widget_class_init	(PanelWidgetClass *klass);
 static void panel_widget_init		(PanelWidget      *panel_widget);
 static int  panel_try_to_set_pixmap     (PanelWidget      *panel,
@@ -56,11 +61,15 @@ int pw_drawer_step = 20;
 int pw_auto_step = 10;
 int pw_minimized_size = 6;
 int pw_minimize_delay = 300;
+int pw_maximize_delay = 0;
 gboolean pw_disable_animations = FALSE;
 PanelMovementType pw_movement_type = PANEL_SWITCH_MOVE;
 int pw_applet_padding = 3;
 int pw_applet_border_padding = 0;
 
+/* translucent panel variables */
+GdkPixmap *desktop_pixmap = NULL;
+
 #define APPLET_EVENT_MASK (GDK_BUTTON_PRESS_MASK |		\
 			   GDK_BUTTON_RELEASE_MASK |		\
 			   GDK_POINTER_MOTION_MASK |		\
@@ -101,7 +110,7 @@ applet_data_compare (AppletData *ad1, AppletData *ad2)
  ************************/
 
 guint
-panel_widget_get_type ()
+panel_widget_get_type (void)
 {
 	static guint panel_widget_type = 0;
 
@@ -958,6 +967,78 @@ kill_cache_on_all_buttons(PanelWidget *panel, gboolean even_no_alpha)
 	}
 }
 
+void
+panel_widget_force_repaint (PanelWidget *panel)
+{
+	gtk_widget_queue_clear (GTK_WIDGET (panel));
+	kill_cache_on_all_buttons(panel, TRUE);
+	send_draw_to_all_applets(panel);
+}
+
+/* set up a pixbuf thats the background of the panel */
+void
+panel_widget_setup_translucent_background (PanelWidget *panel)
+{
+	GdkPixmap *pixmap = NULL;
+	GdkBitmap *bitmap = NULL;
+	GdkPixbuf *background = NULL;
+	GdkPixbuf *background_shaded = NULL;
+	GdkColormap *cmap;
+	GdkWindow *window = gtk_widget_get_parent_window (GTK_WIDGET (panel));
+
+	if (desktop_pixmap && window != NULL) {
+		cmap = gdk_window_get_colormap (window);
+		/* new pixbuf to hold panel background */
+		background = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8,
+				panel->width, panel->height);
+
+		/* copy desktop onto it */
+		background = gdk_pixbuf_get_from_drawable (background,
+				desktop_pixmap, cmap, panel->x, panel->y,
+				0, 0, panel->width, panel->height);
+
+		background_shaded = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 
+				8, panel->width, panel->height);
+
+		gdk_pixbuf_composite_color (background, background_shaded,
+				0, 0, panel->width, panel->height,
+				0.0, 0.0, 1.0, 1.0, 
+				GDK_INTERP_NEAREST, 128,
+				0, 0, 100, 
+				0, 0);
+
+		/* save that pixbuf */
+		gtk_signal_emit(GTK_OBJECT(panel),
+				panel_widget_signals[BACK_CHANGE_SIGNAL],
+				panel->back_type,
+				panel->back_pixmap,
+				&panel->back_color);
+		
+		/* render it onto a pixmap to use to tile the background */
+		gdk_pixbuf_render_pixmap_and_mask (background_shaded, &pixmap, 
+				&bitmap, 0);
+
+		/* and we're finished with it */
+		gdk_pixbuf_ref (background_shaded);
+		if (panel->backpix != NULL) {
+			gdk_pixbuf_unref (panel->backpix);
+		}
+		panel->backpix = background_shaded;
+		gdk_pixbuf_unref (background);
+
+		if (bitmap != NULL) {
+			gdk_bitmap_unref (bitmap);
+		}
+		if (pixmap != NULL) {
+			if (panel->backpixmap != NULL) {
+				gdk_pixmap_unref (panel->backpixmap);
+			}
+			panel->backpixmap = pixmap;
+			gdk_pixmap_ref (panel->backpixmap);
+		}
+	}
+}
+
 static void
 setup_background(PanelWidget *panel, GdkPixbuf **pb, int *scale_w, int *scale_h,
 		 gboolean *rotate)
@@ -1009,6 +1090,9 @@ setup_background(PanelWidget *panel, GdkPixbuf **pb, int *scale_w, int *scale_h,
 				*rotate = TRUE;
 			}
 		}
+	} else if(panel->back_type == PANEL_BACK_TRANSLUCENT) {
+		/* YAK: *shrug* */
+		*pb = panel->backpix;
 	} 
 }
 
@@ -1072,6 +1156,12 @@ panel_widget_draw_all(PanelWidget *panel, GdkRectangle *area)
 			gdk_gc_set_tile(gc, panel->backpixmap);
 			gdk_gc_set_ts_origin(gc,-da.x,-da.y);
 		}
+	} else if(panel->back_type == PANEL_BACK_TRANSLUCENT) {
+		if(panel->backpixmap) {
+			gdk_gc_set_fill(gc, GDK_TILED);
+			gdk_gc_set_tile(gc, panel->backpixmap);
+			gdk_gc_set_ts_origin(gc,-da.x,-da.y);
+		}
 	} else /*COLOR*/ {
 		gdk_gc_set_foreground(gc, &panel->back_color);
 	}
@@ -1400,7 +1490,15 @@ panel_widget_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
 		}
 	}
 
-	
+	if (panel->back_type == PANEL_BACK_TRANSLUCENT &&
+			GTK_WIDGET(panel)->window != NULL) {
+		panel->width = allocation->width;
+		panel->height = allocation->height;
+		gdk_window_get_deskrelative_origin (GTK_WIDGET(panel)->window,
+				&panel->x, &panel->y);
+		panel_widget_setup_translucent_background (panel);
+	}
+
 	for(li=send_move;li!=NULL;li=g_slist_next(li)) {
 		AppletData *ad = li->data;
 		gtk_signal_emit(GTK_OBJECT(panel),
@@ -1648,6 +1746,20 @@ panel_try_to_set_pixmap (PanelWidget *panel, char *pixmap)
 	return TRUE;
 }
 
+static int
+panel_try_to_set_translucent (PanelWidget *panel)
+{
+	g_return_val_if_fail(panel!=NULL,FALSE);
+	g_return_val_if_fail(IS_PANEL_WIDGET(panel),FALSE);
+
+	kill_cache_on_all_buttons(panel, FALSE);
+	send_draw_to_all_applets(panel);
+
+	panel_widget_setup_translucent_background (panel);
+
+	return TRUE;
+}
+
 static void
 panel_widget_realize(GtkWidget *w, gpointer data)
 {
@@ -1661,6 +1773,8 @@ panel_widget_realize(GtkWidget *w, gpointer data)
 	if(panel->back_type == PANEL_BACK_PIXMAP) {
 		if (!panel_try_to_set_pixmap (panel, panel->back_pixmap))
 			panel->back_type = PANEL_BACK_NONE;
+	} else if(panel->back_type == PANEL_BACK_TRANSLUCENT) {
+		/* YAK: hmm */
 	} else if(panel->back_type == PANEL_BACK_COLOR) {
 		panel_try_to_set_back_color(panel, &panel->back_color);
 	}
@@ -1895,7 +2009,7 @@ panel_widget_new (gboolean packed,
 				 "realize",
 				 GTK_SIGNAL_FUNC(panel_widget_realize),
 				 panel);
-	
+
 	return GTK_WIDGET(panel);
 }
 
@@ -2039,11 +2153,11 @@ panel_widget_get_free_space(PanelWidget *panel, GtkWidget *applet)
 		return 0;
 	
 	if(panel->no_padding_on_ends) {
-		right = 0;
-		left = panel->size;
+		right = panel->size;
+		left = 0;
 	} else {
-		right = pw_applet_padding;
-		left = panel->size - pw_applet_padding;
+		right = panel->size - pw_applet_padding;
+		left = pw_applet_padding;
 	}
 	
 	for(li = panel->applet_list; li; li = g_list_next(li)) {
@@ -2402,10 +2516,14 @@ panel_widget_applet_event(GtkWidget *widget, GdkEvent *event, gpointer data)
 #endif
 
 			/* don't propagate this event */
-			if (panel->currently_dragged_applet)
+			if (panel->currently_dragged_applet) {
+				gtk_signal_emit_stop_by_name
+					(GTK_OBJECT (widget), "event");
 				return TRUE;
+			}
 
-			if(bevent->button == 2) {
+			if ( ! commie_mode &&
+			    bevent->button == 2) {
 				/* Start drag */
 				panel_widget_applet_drag_start
 					(panel, widget, PW_DRAG_OFF_CURSOR);
@@ -2416,6 +2534,8 @@ panel_widget_applet_event(GtkWidget *widget, GdkEvent *event, gpointer data)
 
 		case GDK_BUTTON_RELEASE:
 			if (panel->currently_dragged_applet) {
+				gtk_signal_emit_stop_by_name
+					(GTK_OBJECT (widget), "event");
 				panel_widget_applet_drag_end(panel);
 				return TRUE;
 			}
@@ -2814,7 +2934,7 @@ panel_widget_change_params(PanelWidget *panel,
 {
 	PanelOrientation oldorient;
 	int oldsz;
-	int change_back = FALSE;
+	gboolean change_back = FALSE;
 
 	g_return_if_fail(panel!=NULL);
 	g_return_if_fail(IS_PANEL_WIDGET(panel));
@@ -2877,22 +2997,24 @@ panel_widget_change_params(PanelWidget *panel,
 		/* we will queue resize and redraw anyhow */
 	} else if(back_type == PANEL_BACK_COLOR) {
 		panel_try_to_set_back_color(panel, &panel->back_color);
+	} else if(back_type == PANEL_BACK_TRANSLUCENT) {
+		panel_try_to_set_translucent (panel);
 	}
 
 	/* let the applets know we changed the background */
-	if(change_back) {
-		gtk_signal_emit(GTK_OBJECT(panel),
-				panel_widget_signals[BACK_CHANGE_SIGNAL],
-				panel->back_type,
-				panel->back_pixmap,
-				&panel->back_color);
+	if (change_back) {
+		gtk_signal_emit (GTK_OBJECT (panel),
+				 panel_widget_signals[BACK_CHANGE_SIGNAL],
+				 panel->back_type,
+				 panel->back_pixmap,
+				 &panel->back_color);
 	}
 
 	panel->no_padding_on_ends = no_padding_on_ends;
 
 	/* inhibit draws until we resize */
 	panel->inhibit_draw = TRUE;
-	gtk_widget_queue_resize(GTK_WIDGET(panel));
+	gtk_widget_queue_resize (GTK_WIDGET (panel));
 }
 
 void
@@ -2914,36 +3036,40 @@ panel_widget_change_orient(PanelWidget *panel,
 
 /*change global params*/
 void
-panel_widget_change_global(int explicit_step,
-			   int auto_step,
-			   int drawer_step,
-			   int minimized_size,
-			   int minimize_delay,
-			   PanelMovementType move_type,
-			   gboolean disable_animations,
-			   int applet_padding,
-			   int applet_border_padding)
+panel_widget_change_global (int explicit_step,
+			    int auto_step,
+			    int drawer_step,
+			    int minimized_size,
+			    int minimize_delay,
+			    int maximize_delay,
+			    PanelMovementType move_type,
+			    gboolean disable_animations,
+			    int applet_padding,
+			    int applet_border_padding)
 {
-	if(explicit_step>0)
+	if (explicit_step > 0)
 		pw_explicit_step=explicit_step;
-	if(auto_step>0)
+	if (auto_step > 0)
 		pw_auto_step=auto_step;
-	if(drawer_step>0)
+	if (drawer_step > 0)
 		pw_drawer_step=drawer_step;
-	if(minimized_size>0)
+	if (minimized_size > 0)
 		pw_minimized_size=minimized_size;
-	if(minimize_delay>=0)
+	if (minimize_delay >= 0)
 		pw_minimize_delay=minimize_delay;
+	if (maximize_delay >= 0)
+		pw_maximize_delay=maximize_delay;
 	pw_movement_type = move_type;
 	pw_disable_animations = disable_animations;
 
 	/*change padding on all panels NOW*/
-	if((pw_applet_padding != applet_padding) || (pw_applet_border_padding != applet_border_padding)) {
+	if( (pw_applet_padding != applet_padding) ||
+	    (pw_applet_border_padding != applet_border_padding)) {
 		GSList *li;
 		pw_applet_padding = applet_padding;
 		pw_applet_border_padding = applet_border_padding;
-		for(li=panels;li!=NULL;li=g_slist_next(li))
-			gtk_widget_queue_resize(li->data);
+		for (li = panels; li != NULL; li = li->next)
+			gtk_widget_queue_resize (li->data);
 	}
 }
 
@@ -2951,13 +3077,13 @@ panel_widget_change_global(int explicit_step,
    color and w, and h to the area if the background is one color
    only, otherwise normally return an rgb and set r, g, b to -1 */
 void
-panel_widget_get_applet_rgb_bg(PanelWidget *panel,
-			       GtkWidget *applet,
-			       guchar **rgb,
-			       int *w, int *h,
-			       int *rowstride,
-			       gboolean color_only,
-			       int *r, int *g, int *b)
+panel_widget_get_applet_rgb_bg (PanelWidget *panel,
+				GtkWidget *applet,
+				guchar **rgb,
+				int *w, int *h,
+				int *rowstride,
+				gboolean color_only,
+				int *r, int *g, int *b)
 {
 	GtkWidget *widget;
 
@@ -2970,24 +3096,25 @@ panel_widget_get_applet_rgb_bg(PanelWidget *panel,
 	*w = *h = *rowstride = 0;
 	*r = *g = *b = -1;
 
-	g_return_if_fail(panel!=NULL);
-	g_return_if_fail(IS_PANEL_WIDGET(panel));
-	g_return_if_fail(applet!=NULL);
-	g_return_if_fail(GTK_IS_WIDGET(applet));
+	g_return_if_fail (panel != NULL);
+	g_return_if_fail (IS_PANEL_WIDGET (panel));
+	g_return_if_fail (applet != NULL);
+	g_return_if_fail (GTK_IS_WIDGET (applet));
 
-	widget = GTK_WIDGET(panel);
+	widget = GTK_WIDGET (panel);
 
-	if(!GTK_WIDGET_DRAWABLE(widget) ||
+	if( ! GTK_WIDGET_DRAWABLE (widget) ||
 	   widget->allocation.width <= 0 ||
 	   widget->allocation.height <= 0)
 		return;
 
-	setup_background(panel, &pb, &scale_w, &scale_h, &rotate);
+	setup_background (panel, &pb, &scale_w, &scale_h, &rotate);
 	
 	*w = applet->allocation.width;
 	*h = applet->allocation.height;
 	
-	if(color_only && !pb) {
+	if (color_only &&
+	    pb == NULL) {
 		if(panel->back_type != PANEL_BACK_COLOR) {
 			GtkWidget *widget = GTK_WIDGET(panel);
 			/* convert to 8 bit per channel */
@@ -3002,12 +3129,13 @@ panel_widget_get_applet_rgb_bg(PanelWidget *panel,
 		}
 		return;
 	}
-	*rowstride = applet->allocation.width*3;
+	*rowstride = applet->allocation.width * 3;
 
-	*rgb = g_new0(guchar, (*h)*(*rowstride));
+	*rgb = g_new0(guchar,
+		      (*h) * (*rowstride));
 
-	make_background(panel, *rgb,
-			applet->allocation.x,
-			applet->allocation.y,
-			*w,*h, pb, scale_w, scale_h, rotate);
+	make_background (panel, *rgb,
+			 applet->allocation.x,
+			 applet->allocation.y,
+			 *w, *h, pb, scale_w, scale_h, rotate);
 }
